<?php

// Used to generate a scatter plot graph image that contains player, town, and quest positions on an x,y grid. 
// This graph can then be overlaid onto an image of some sort, creating a visual map.
// This file accepts the following inputs in the URL:
//    Height - Number of pixels for the image height
//    Width  - Number of pixels for the image width.  Really should be the same as the height, but I left the option available, if you wanted to skew the map for some reason
//    showuser - True/False - Shows the current user position
//    showquest - True/False - Shows the current user's current story position
//    showtowns - True/False - Shows all town positions for the current user's world
//    showguild - True/False - Shows position of current user's guild's members that are in the same world as the current user
//    showallusers - True/False - Shows position of all users that are in the same world as the current user
//    showlabels - True/False - Shows map title, and legend.

// Grab values from URL, and set to default in none.
if (isset($_GET["height"])) {
   $height = $_GET["height"];
   }
   else {
   $height = 600;
   }
if (isset($_GET["width"])) {
   $width= $_GET["width"];
   }
   else {
   $width = 600;
   }
if (isset($_GET["showuser"])) {
   $showuser= $_GET["showuser"];
   }
   else {
   $showuser= 1;
   }
if (isset($_GET["showquest"])) {
   $showquest = $_GET["showquest"];
   }
   else {
   $showquest = 1;
   }
if (isset($_GET["showtowns"])) {
   $showtowns = $_GET["showtowns"];
   }
   else {
   $showtowns = 1;
   }
   if (isset($_GET["showguild"])) {
   $showguild = $_GET["showguild"];
   }
   else {
   $showguild = 0;
   }
if (isset($_GET["showallusers"])) {
   $showallusers = $_GET["showallusers"];
   }
   else {
   $showallusers = 0;
   }
if (isset($_GET["showlabels"])) {
   $showlabels = $_GET["showlabels"];
   }
   else {
   $showlabels = 0;
   }

// Pull in required functions, variables, etc.
require_once 'phplot.php';
include("lib.php");
include("globals.php");

// Create our arrays
$data = array();
$legend_text = array();

function get_label($ignored_label, $data, $row = NULL, $ignored_column = NULL)  //  Allows you to use place text labels next to points
{
    return $data[$row][0];
}

// Plot towns
if ($showtowns) {
   $towns = dorow(doquery("SELECT * FROM <<towns>> WHERE world='".$worldrow["id"]."'"));
   foreach ($towns as $result_row) {
       $row = array($result_row['name'], $result_row['longitude'], '', '', $result_row['latitude'], '', '');// put the longitude in the third Y column to paint the town black
       $data[] = $row;
   }
}

// Plot guild members and all other users, if enabled
if ($showguild && $showallusers && $userrow["guild"] !=0) {
   //do guild members
	
   $guildusers = dorow(doquery("SELECT * FROM <<users>> WHERE world='".$worldrow["id"]."' AND UNIX_TIMESTAMP(onlinetime) >= '".(time()-600)."' AND id != '".$userrow["id"]."' AND guild= '".$userrow["guild"]."'"), "id");
   foreach ($guilduses as $result_row) {
      $row = array($result_row['name'], $result_row['longitude'], '', '', '', $result_row['latitude'], '');// put the longitude in the fourth Y column to paint the users red
      $data[] = $row;
   }
   
   //do all other users
   $allusers = dorow(doquery("SELECT * FROM <<users>> WHERE world='".$worldrow["id"]."' AND UNIX_TIMESTAMP(onlinetime) >= '".(time()-600)."' AND id != '".$userrow["id"]."' AND guild!= '".$userrow["guild"]."'"), "id");
   foreach ($allusers as $result_row) {
      $row = array($result_row['name'], $result_row['longitude'], '', '', '', '', $result_row['latitude']);// put the longitude in the fifth Y column to paint the users grey
      $data[] = $row;
   }
}
elseif ($showguild & $userrow["guild"] !=0) {
   //do guild members
   $guildusers = dorow(doquery("SELECT * FROM <<users>> WHERE world='".$worldrow["id"]."' AND UNIX_TIMESTAMP(onlinetime) >= '".(time()-600)."' AND id != '".$userrow["id"]."' AND guild= '".$userrow["guild"]."'"), "id");
   foreach ($guilduses as $result_row) {
       $row = array($result_row['name'], $result_row['longitude'], '', '', '', $result_row['latitude'], '');// put the longitude in the fourth Y column to paint the users red
       $data[] = $row;
   }
}
elseif ($showallusers) {
   	//do all other users
	$allusers = dorow(doquery("SELECT * FROM <<users>> WHERE world='".$worldrow["id"]."' AND UNIX_TIMESTAMP(onlinetime) >= '".(time()-600)."' AND id != '".$userrow["id"]."'"), "id");
   foreach ($allusers as $result_row) {
       $row = array($result_row['name'], $result_row['longitude'], '', '', '', '', $result_row['latitude']);// put the longitude in the fifth Y column to paint the users gray
       $data[] = $row;
   }
}

//Plot the user
if ($showuser) {
	$data[] = array($userrow["charname"], $userrow["longitude"], $userrow["latitude"], '', '', '', ''); // put the longitude in the first Y column to paint the user red
}

// Now do quests
if ($showquest) {
   if ($userrow["story"] != "0" && $userrow["story"] != "9999") {
       $data[] = array('Quest', $userrow["storylon"], '', $userrow["storylat"]. '', '', '');  // put the longitude in the second Y column to paint the quest blue
   }
}

if ($showuser) {$legend_text[] = 'You';}
if ($showquest) {$legend_text[] = 'Quest';}
if ($showtowns) {$legend_text[] = 'Towns';}
if ($showallusers) {$legend_text[] = 'Guild Members';}
if ($showallusers) {$legend_text[] = 'Other Users';}


// required settings
$plot = new PHPlot($height, $width); // do not change
$plot->SetDataType('data-data'); // do not change
$plot->SetDataValues($data); // do not change
$plot->SetPlotType('points'); // do not change
$plot->SetPlotAreaWorld(-1 * $worldrow["size"], -1 * $worldrow["size"], $worldrow["size"], $worldrow["size"]); // do not change
$plot->SetMarginsPixels(0,0,0,0); // do not change
$plot->SetXAxisPosition(0); // do not change
$plot->SetYAxisPosition(0); // do not change

// formatting
$plot->SetBackgroundColor('yellow'); // use a color not used anywhere else in the graph
$plot->SetTransparentColor('yellow'); // set background to transparent
$plot->SetFileFormat('png'); // needs to be png or gif if transparency is used.
$plot->SetGridColor('yellow');
$plot->SetXTickPos('none');
$plot->SetXTickLabelPos('none');
$plot->SetXTickIncrement($worldrow["size"]);
$plot->SetYTickPos('none');
$plot->SetYTickLabelPos('none');
$plot->SetYTickIncrement($worldrow["size"]);
$plot->SetPlotBorderType('full');
if ($showlabels) {
	$plot->SetTitle($worldrow["name"].' Map');
    $plot->SetYDataLabelType('custom', 'get_label', $data);	// Displays text labels next to points
	$plot->SetYDataLabelPos('plotin');
	$plot->SetLegend($legend_text);
	$plot->SetLegendUseShapes(true);
} 
else {
	$plot->SetTitle('');
	$plot->SetXDataLabelPos('none'); 
}

// Set colors for 5 data sets:
$plot->SetDataColors(array('red', 'blue', 'grey', 'red', 'grey'));
// Fill in legend
$plot->SetPointShapes(array('diamond','dot','home', 'rect', 'target')); 

$plot->Draw